@@ -15,6 +15,7 @@
 // limitations under the License.
 // ------------------------------------------------------------------------
 
+// using std::cerr; // hack: comment this line to avoid CRAN checks
 using std::cout;
 using std::endl;
 using std::ios;
@@ -125,6 +126,8 @@ class op_diagmat;
 class op_trimat;
 class op_vectorise_row;
 class op_vectorise_col;
+class op_symmatu;
+class op_symmatl;
 
 class op_row_as_mat;
 class op_col_as_mat;
