@@ -249,62 +249,6 @@ operator+(const typename T1::elem_type k, const T1& X) {
   return SpToDOp<T1, op_sp_plus>(X, k);  // NOTE: swapped order
 }
 
-// TODO: this is an uncommon use case; remove?
-//! multiple applications of add/subtract scalars can be condensed
-template <typename T1, typename op_type>
-inline typename enable_if2<(is_arma_sparse_type<T1>::value &&
-                            (is_same_type<op_type, op_sp_plus>::value ||
-                             is_same_type<op_type, op_sp_minus_post>::value)),
-                           const SpToDOp<T1, op_sp_plus> >::result
-operator+(const SpToDOp<T1, op_type>& x, const typename T1::elem_type k) {
-  arma_debug_sigprint();
-
-  const typename T1::elem_type aux =
-      (is_same_type<op_type, op_sp_plus>::value) ? x.aux : -x.aux;
-
-  return SpToDOp<T1, op_sp_plus>(x.m, aux + k);
-}
-
-// TODO: this is an uncommon use case; remove?
-//! multiple applications of add/subtract scalars can be condensed
-template <typename T1, typename op_type>
-inline typename enable_if2<(is_arma_sparse_type<T1>::value &&
-                            is_same_type<op_type, op_sp_minus_pre>::value),
-                           const SpToDOp<T1, op_sp_minus_pre> >::result
-operator+(const SpToDOp<T1, op_type>& x, const typename T1::elem_type k) {
-  arma_debug_sigprint();
-
-  return SpToDOp<T1, op_sp_minus_pre>(x.m, x.aux + k);
-}
-
-// TODO: this is an uncommon use case; remove?
-//! multiple applications of add/subtract scalars can be condensed
-template <typename T1, typename op_type>
-inline typename enable_if2<(is_arma_sparse_type<T1>::value &&
-                            (is_same_type<op_type, op_sp_plus>::value ||
-                             is_same_type<op_type, op_sp_minus_post>::value)),
-                           const SpToDOp<T1, op_sp_plus> >::result
-operator+(const typename T1::elem_type k, const SpToDOp<T1, op_type>& x) {
-  arma_debug_sigprint();
-
-  const typename T1::elem_type aux =
-      (is_same_type<op_type, op_sp_plus>::value) ? x.aux : -x.aux;
-
-  return SpToDOp<T1, op_sp_plus>(x.m, aux + k);
-}
-
-// TODO: this is an uncommon use case; remove?
-//! multiple applications of add/subtract scalars can be condensed
-template <typename T1, typename op_type>
-inline typename enable_if2<(is_arma_sparse_type<T1>::value &&
-                            is_same_type<op_type, op_sp_minus_pre>::value),
-                           const SpToDOp<T1, op_sp_minus_pre> >::result
-operator+(const typename T1::elem_type k, const SpToDOp<T1, op_type>& x) {
-  arma_debug_sigprint();
-
-  return SpToDOp<T1, op_sp_minus_pre>(x.m, x.aux + k);
-}
-
 template <typename parent, unsigned int mode, typename T2>
 arma_inline Mat<typename parent::elem_type> operator+(
     const subview_each1<parent, mode>& X, const Base<typename parent::elem_type, T2>& Y) {
